Name:		minetest
Version:	0.4.16
Release:	%mkrel 1
Summary:	An InfiniMiner/Minecraft inspired game
Group:		Games/Simulation
License:	LGPLv2+ and CC-BY-SA 3.0
URL:		http://minetest.net
Source0:	https://github.com/minetest/minetest/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/minetest/minetest_game/archive/%{version}/%{name}_game-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	bzip2-devel
BuildRequires:	gettext
BuildRequires:	gmp-devel
BuildRequires:	irrlicht-devel
BuildRequires:	jpeg-devel
# Curl features crash when using system jsoncpp
# https://github.com/minetest/minetest/issues/1793
#BuildRequires:	jsoncpp-devel
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(jthread)
BuildRequires:	pkgconfig(leveldb)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(luajit)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(vorbisfile)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(zlib)

%description
One of the first InfiniMiner/Minecraft inspired games with a goal of taking
the survival multiplayer gameplay to a slightly different direction.

This game is under development, and as of now, the game does not really
differ from Minecraft except for having a lot less features. Still, playing
is quite fun already, especially for people who have not been able to
experience Minecraft.

%prep
%setup -q -a 1
%autopatch -p1

%build
%cmake	-DRUN_IN_PLACE=0 \
	-DBUILD_SHARED_LIBS=OFF \
	-DCUSTOM_BINDIR:STRING=%{_gamesbindir} \
	-DCUSTOM_LOCALEDIR:STRING=%{_datadir}/locale \
	-DCUSTOM_SHAREDIR:STRING=%{_gamesdatadir}/%{name} \
	-DENABLE_CURL:BOOL=ON \
	-DENABLE_FREETYPE:BOOL=ON \
	-DENABLE_GETTEXT:BOOL=ON \
	-DENABLE_LEVELDB:BOOL=ON \
	-DENABLE_REDIS:BOOL=OFF \
	-DENABLE_SOUND:BOOL=ON
%make_build

%install
%make_install -C build
install -d %{buildroot}%{_gamesdatadir}/%{name}/games/%{name}_game
cp -r %{name}_game-%{version}/* %{buildroot}%{_gamesdatadir}/%{name}/games/%{name}_game

rm -rf %{buildroot}%{_gamesdatadir}/%{name}/client/serverlist/.gitignore

%find_lang %{name}

%files -f %{name}.lang
%doc doc/*.txt README.txt minetest.conf.example
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_datadir}/applications/net.minetest.%{name}.desktop
%{_datadir}/metainfo/net.minetest.%{name}.appdata.xml
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}.6*
%{_mandir}/man6/%{name}server.6*


%changelog
* Sat Jun 03 2017 akien <akien> 0.4.16-1.mga6
+ Revision: 1106388
- Version 0.4.16

* Fri Mar 24 2017 akien <akien> 0.4.15-3.mga6
+ Revision: 1094693
- Rebuild for jthread 1.3.3

* Sun Jan 01 2017 akien <akien> 0.4.15-2.mga6
+ Revision: 1079435
- Rebuild for leveldb 1.19

* Fri Dec 23 2016 akien <akien> 0.4.15-1.mga6
+ Revision: 1076544
- Version 0.4.15

* Mon May 16 2016 akien <akien> 0.4.14-1.mga6
+ Revision: 1016150
- Version 0.4.14

* Wed Mar 16 2016 daviddavid <daviddavid> 0.4.13-3.mga6
+ Revision: 991760
- rename and rediff unappliable desktop patch (since fixed autopatch)

* Mon Feb 15 2016 umeabot <umeabot> 0.4.13-2.mga6
+ Revision: 961407
- Mageia 6 Mass Rebuild

* Sun Sep 13 2015 akien <akien> 0.4.13-1.mga6
+ Revision: 878931
- Build against system gmp
- Version 0.4.13

* Sat Aug 29 2015 cjw <cjw> 0.4.12-2.mga6
+ Revision: 870813
- rebuild with gcc 5

* Sun Feb 22 2015 akien <akien> 0.4.12-1.mga5
+ Revision: 816390
- Add patch inspired from a Debian freeminer patch to properly lookup for the translations
- Version 0.4.12

* Sat Dec 27 2014 akien <akien> 0.4.11-1.mga5
+ Revision: 806557
- Version 0.4.11

* Mon Dec 01 2014 akien <akien> 0.4.10-6.mga5
+ Revision: 800225
- Enable cURL support for online multiplayer features
- System jsoncpp does not work with cURL support, used bundled version
- Disable hiredis support (optional)

* Wed Oct 15 2014 umeabot <umeabot> 0.4.10-5.mga5
+ Revision: 745299
- Second Mageia 5 Mass Rebuild

* Wed Sep 17 2014 akien <akien> 0.4.10-4.mga5
+ Revision: 693180
- Enable freetype2 and leveldb support

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Wed Aug 27 2014 akien <akien> 0.4.10-1.mga5
+ Revision: 668844
- Fix unfound translations using a symlink
- Version 0.4.10

* Sun Feb 09 2014 akien <akien> 0.4.9-1.mga5
+ Revision: 587283
- New upstream release 0.4.9: http://dev.minetest.net/Changelog#0.4.8_.E2.86.92_0.4.9

* Sun Nov 24 2013 akien <akien> 0.4.8-1.mga5
+ Revision: 552718
- New upstream release 0.4.8: http://dev.minetest.net/Changelog#0.4.7_.E2.86.92_0.4.8
- Removed jthread patch, no longer necessary
- Added patch to fix locale dir instead of relying on a sed instruction
- Added patch to change desktop category

* Mon Oct 21 2013 umeabot <umeabot> 0.4.7-3.mga4
+ Revision: 539913
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 dams <dams> 0.4.7-2.mga4
+ Revision: 493064
- update specfile
- clean %%cmake options
- enable back parallel build

* Tue Oct 08 2013 dams <dams> 0.4.7-1.mga4
+ Revision: 493051
- new version 0.4.7
- add a patch to fix build with jthread
- add a patch to fix jsoncpp deps

* Sat Jan 12 2013 umeabot <umeabot> 0.4.3-3.mga3
+ Revision: 360093
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dams <dams> 0.4.3-2.mga3
+ Revision: 293095
- do not use embedded jthread anymore (+ patch from Mandriva to fix build)

* Mon Sep 10 2012 dams <dams> 0.4.3-1.mga3
+ Revision: 291962
- add a patch to fix build of jthread (embedded): pthread needed
- new version 0.4.3
- clean specfile
- remove useless patch
- update %%cmake options
- imported package minetest

